Branch: master

32f50cd6 2014-08-07 17:24:38 Timothy Pearson
Rename the string kde toolbar widget
M kate/plugins/isearch/ISearchPlugin.cpp
M tdestyles/highcolor/highcolor.cpp
M tdestyles/keramik/keramik.cpp
M tdestyles/kthemestyle/kthemestyle.cpp
M tdestyles/plastik/plastik.cpp
M tdeui/tdelistviewsearchline.cpp
M tdeui/tdetoolbarlabelaction.cpp
M tdeui/tdetoolbarlabelaction.h
M tdeui/tests/tdetoolbarlabelactiontest.cpp
diff --git a/kate/plugins/isearch/ISearchPlugin.cpp b/kate/plugins/isearch/ISearchPlugin.cpp
index 7cb01cc..4ee93cb 100644
--- a/kate/plugins/isearch/ISearchPlugin.cpp
+++ b/kate/plugins/isearch/ISearchPlugin.cpp
@@ -73,7 +73,7 @@
 		this, TQT_SLOT(slotSearchBackwardAction()),
 		actionCollection(), "edit_isearch_reverse" );
 
-	m_label = new TQLabel( i18n("I-Search:"), 0L, "kde toolbar widget" );
+	m_label = new TQLabel( i18n("I-Search:"), 0L, "tde toolbar widget" );
 	KWidgetAction* labelAction = new KWidgetAction(
 		m_label,
 		i18n("I-Search:"), 0, 0, 0,
diff --git a/tdestyles/kthemestyle/kthemestyle.cpp b/tdestyles/kthemestyle/kthemestyle.cpp
index f09482c..5ddbb38 100644
--- a/tdestyles/kthemestyle/kthemestyle.cpp
+++ b/tdestyles/kthemestyle/kthemestyle.cpp
@@ -506,7 +506,7 @@
                 w->setPalette(pal);
             }
         }
-        if (!qstrcmp(object->name(), "kde toolbar widget") && object->inherits(TQLABEL_OBJECT_NAME_STRING))
+        if (!qstrcmp(object->name(), "tde toolbar widget") && object->inherits(TQLABEL_OBJECT_NAME_STRING))
         {
             TQWidget* lb = TQT_TQWIDGET(object);
             if (lb->backgroundMode() == TQt::PaletteButton)
@@ -526,7 +526,7 @@
         if (::tqqt_cast<TQStatusBar*>(w))
             w->setPaletteBackgroundColor(TQApplication::palette().color(TQPalette::Normal, TQColorGroup::Background));
 
-        if (::tqqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "kde toolbar widget"))
+        if (::tqqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "tde toolbar widget"))
             installObjectEventHandler(ceData, elementFlags, ptr, this);
 
         if (w->backgroundPixmap() && !w->isTopLevel() && 
@@ -644,7 +644,7 @@
         }
 
         //Toolbar labels should nornally be PaletteButton
-        if ( ::tqqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "kde toolbar widget"))
+        if ( ::tqqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "tde toolbar widget"))
             w->setBackgroundMode( TQWidget::PaletteButton );
 
         //The same for menu bars, popup menus
diff --git a/tdestyles/plastik/plastik.cpp b/tdestyles/plastik/plastik.cpp
index 7abba20..b2801ef 100644
--- a/tdestyles/plastik/plastik.cpp
+++ b/tdestyles/plastik/plastik.cpp
@@ -261,7 +261,7 @@
 		installObjectEventHandler(ceData, elementFlags, ptr, this);
 	} else if (::tqqt_cast<TQPopupMenu*>(widget)) {
 		widget->setBackgroundMode( NoBackground );
-	} else if ( !qstrcmp(widget->name(), "kde toolbar widget") ) {
+	} else if ( !qstrcmp(widget->name(), "tde toolbar widget") ) {
 		installObjectEventHandler(ceData, elementFlags, ptr, this);
 	}
 	
@@ -301,7 +301,7 @@
 		removeObjectEventHandler(ceData, elementFlags, ptr, this);
 	} else if (::tqqt_cast<TQPopupMenu*>(widget)) {
 		widget->setBackgroundMode( PaletteBackground );
-	} else if ( !qstrcmp(widget->name(), "kde toolbar widget") ) {
+	} else if ( !qstrcmp(widget->name(), "tde toolbar widget") ) {
 		removeObjectEventHandler(ceData, elementFlags, ptr, this);
 	}
 	
@@ -3510,7 +3510,7 @@
 		animationTimer->start( 50, false );
 		}
 	}
-	if ( !qstrcmp(obj->name(), "kde toolbar widget") )
+	if ( !qstrcmp(obj->name(), "tde toolbar widget") )
 	{
 		TQWidget* lb = TQT_TQWIDGET(obj);
 		if (lb->backgroundMode() == TQt::PaletteButton)
diff --git a/tdeui/tdelistviewsearchline.cpp b/tdeui/tdelistviewsearchline.cpp
index b74b4d1..50ad3d2 100644
--- a/tdeui/tdelistviewsearchline.cpp
+++ b/tdeui/tdelistviewsearchline.cpp
@@ -452,7 +452,7 @@
 
     d->clearButton->show();
 
-    TQLabel *label = new TQLabel(i18n("S&earch:"), this, "kde toolbar widget");
+    TQLabel *label = new TQLabel(i18n("S&earch:"), this, "tde toolbar widget");
 
     d->searchLine = createSearchLine(d->listView);
     d->searchLine->show();
diff --git a/tdeui/tdetoolbarlabelaction.cpp b/tdeui/tdetoolbarlabelaction.cpp
index dcac8fc..c88f684 100644
--- a/tdeui/tdetoolbarlabelaction.cpp
+++ b/tdeui/tdetoolbarlabelaction.cpp
@@ -38,7 +38,7 @@
 					 const char *slot,
 					 TDEActionCollection *parent,
 					 const char *name)
-  : KWidgetAction(new TQLabel(text, 0, "kde toolbar widget"), text, cut,
+  : KWidgetAction(new TQLabel(text, 0, "tde toolbar widget"), text, cut,
 		  receiver, slot, parent, name), 
     d(new TDEToolBarLabelActionPrivate)
 {
@@ -52,7 +52,7 @@
 					 const char *slot,
  					 TDEActionCollection *parent, 
 					 const char *name)
-  : KWidgetAction(new TQLabel(buddy, text, 0, "kde toolbar widget"), text, 
+  : KWidgetAction(new TQLabel(buddy, text, 0, "tde toolbar widget"), text, 
 		  cut, receiver, slot, parent, name),
     d(new TDEToolBarLabelActionPrivate)
 {
@@ -68,7 +68,7 @@
   : KWidgetAction(label, label->text(), cut, receiver, slot, parent, name),
     d(new TDEToolBarLabelActionPrivate)
 {
-  Q_ASSERT(TQString::fromLatin1("kde toolbar widget") == label->name());
+  Q_ASSERT(TQString::fromLatin1("tde toolbar widget") == label->name());
   init();
 }
 
diff --git a/tdeui/tdetoolbarlabelaction.h b/tdeui/tdetoolbarlabelaction.h
index 3fef739..c330c92 100644
--- a/tdeui/tdetoolbarlabelaction.h
+++ b/tdeui/tdetoolbarlabelaction.h
@@ -87,7 +87,7 @@
    * transferred to the action and the label is deleted when the action is
    * deleted. So you shouldn't hold any pointers to the label.
    *
-   * It's important that the label's name is set to "kde toolbar widget" in
+   * It's important that the label's name is set to "tde toolbar widget" in
    * its constructor, otherwise it is not correctly rendered in some kde
    * styles.
    *
diff --git a/tdeui/tests/tdetoolbarlabelactiontest.cpp b/tdeui/tests/tdetoolbarlabelactiontest.cpp
index b919c27..7c6222a 100644
--- a/tdeui/tests/tdetoolbarlabelactiontest.cpp
+++ b/tdeui/tests/tdetoolbarlabelactiontest.cpp
@@ -40,10 +40,10 @@
 
     KSqueezedTextLabel* accel = new KSqueezedTextLabel
       ("&Really long, long, long and boring text goes here", main, 
-       "kde toolbar widget");
+       "tde toolbar widget");
     new KSqueezedTextLabel
       ("Really long, long, long and boring text goes here", main, 
-       "kde toolbar widget");
+       "tde toolbar widget");
 
 
     // first constructor
@@ -67,7 +67,7 @@
      // third constructor
     TQLabel* customLabel =  new KSqueezedTextLabel
       ("&Really long, long, long and boring text goes here", this, 
-        "kde toolbar widget");
+        "tde toolbar widget");
 
     TDEToolBarLabelAction* label3 = new TDEToolBarLabelAction(customLabel, 0, 0, 0,
  							  actionCollection(),
diff --git a/tdestyles/highcolor/highcolor.cpp b/tdestyles/highcolor/highcolor.cpp
index 353fee3..2017c40 100644
--- a/tdestyles/highcolor/highcolor.cpp
+++ b/tdestyles/highcolor/highcolor.cpp
@@ -96,7 +96,7 @@
 static const int itemVMargin     = 0;
 static const int arrowHMargin    = 6;
 static const int rightBorder     = 12;
-static const char* kdeToolbarWidget = "kde toolbar widget";
+static const char* kdeToolbarWidget = "tde toolbar widget";
 
 // ---------------------------------------------------------------------------
 
@@ -2023,7 +2023,7 @@
 		if ( object->parent() && !qstrcmp( object->name(), kdeToolbarWidget ) )
 		{
 			// Draw a gradient background for custom widgets in the toolbar
 			// that have specified a "kde toolbar widget" name.
 			// FIXME
 			// This currently requires direct widget access
 			// Is there any way to do this without it?
@@ -2023,7 +2023,7 @@
 		{
 			// Draw a gradient background for custom widgets in the toolbar
-			// that have specified a "kde toolbar widget" name.
+			// that have specified a "tde toolbar widget" name.
 			// FIXME
 			// This currently requires direct widget access
diff --git a/tdestyles/keramik/keramik.cpp b/tdestyles/keramik/keramik.cpp
index 759f3d7..f3a5ee0 100644
--- a/tdestyles/keramik/keramik.cpp
+++ b/tdestyles/keramik/keramik.cpp
@@ -113,7 +113,7 @@
 	const int itemVMargin     = 0;
 	const int arrowHMargin    = 6;
 	const int rightBorder     = 12;
-	const char* kdeToolbarWidget = "kde toolbar widget";
+	const char* kdeToolbarWidget = "tde toolbar widget";
 
 	const int smallButMaxW    = 27;
 	const int smallButMaxH    = 20;
@@ -482,7 +482,7 @@
 static void renderToolbarWidgetBackground(TQPainter* painter, const TQStyleControlElementData &ceData, const TQStyle::ControlElementFlags elementFlags, const TQWidget* widget)
 {
 	// Draw a gradient background for custom widgets in the toolbar
 	// that have specified a "kde toolbar widget" name, or
 	// are caught as toolbar widgets otherwise
 
 	// Find the top-level toolbar of this widget, since it may be nested in other
@@ -2917,7 +2917,7 @@
 				object->parent() && !qstrcmp(object->name(), kdeToolbarWidget) )
 		{
 			// Draw a gradient background for custom widgets in the toolbar
 			// that have specified a "kde toolbar widget" name.
 			renderToolbarWidgetBackground(0, ceData, elementFlags, TQT_TQWIDGET(object));
 	
 			return false;	// Now draw the contents
@@ -482,7 +482,7 @@
 {
 	// Draw a gradient background for custom widgets in the toolbar
-	// that have specified a "kde toolbar widget" name, or
+	// that have specified a "tde toolbar widget" name, or
 	// are caught as toolbar widgets otherwise
 
@@ -2917,7 +2917,7 @@
 		{
 			// Draw a gradient background for custom widgets in the toolbar
-			// that have specified a "kde toolbar widget" name.
+			// that have specified a "tde toolbar widget" name.
 			renderToolbarWidgetBackground(0, ceData, elementFlags, TQT_TQWIDGET(object));
 	